@@ -1,5 +1,5 @@
 var interfacecom_1_1sun_1_1star_1_1frame_1_1XModuleManager2 =
 [
-    [ "XNameReplace", "interfacecom_1_1sun_1_1star_1_1frame_1_1XModuleManager2.html#ab805438bc151f39e77bee38ebae9528c", null ],
+    [ "::com::sun::star::container::XNameReplace", "interfacecom_1_1sun_1_1star_1_1frame_1_1XModuleManager2.html#ab805438bc151f39e77bee38ebae9528c", null ],
     [ "XModuleManager", "interfacecom_1_1sun_1_1star_1_1frame_1_1XModuleManager2.html#aa355cc5036fd28c3489d45bbe1920979", null ]
 ];
\ No newline at end of file
