@@ -2,5 +2,5 @@ var servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess =
 [
     [ "HierarchyAccess", "servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html#af6d1e0509b041fca3140f08d02d1a859", null ],
     [ "SimpleSetAccess", "servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html#a98fd9a74c6a75a1735440caaca9dd4aa", null ],
-    [ "XContainer", "servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ]
+    [ "com::sun::star::container::XContainer", "servicecom_1_1sun_1_1star_1_1configuration_1_1SetAccess.html#a7a2fee03a55e1e4354eaea94bdaa4e4d", null ]
 ];
\ No newline at end of file
