@@ -1,5 +1,5 @@
 var servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HiddenControl =
 [
-    [ "FormComponent", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HiddenControl.html#aea7e1c4e549533be5dffe5f7f4b740c6", null ],
+    [ "com::sun::star::form::FormComponent", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HiddenControl.html#aea7e1c4e549533be5dffe5f7f4b740c6", null ],
     [ "HiddenValue", "servicecom_1_1sun_1_1star_1_1form_1_1component_1_1HiddenControl.html#acddec9139285278502382943ac5572dc", null ]
 ];
\ No newline at end of file
