@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2 =
 [
-    [ "TableSortDescriptor2", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a941d7336f572db82e3d62705d8e2187e", null ],
+    [ "com::sun::star::table::TableSortDescriptor2", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a941d7336f572db82e3d62705d8e2187e", null ],
     [ "BindFormatsToContent", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#acfc537e4dc64cdc14bddddb534177a9e", null ],
     [ "ContainsHeader", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a5065e7c42974615d07286e452e171dc2", null ],
     [ "CopyOutputData", "servicecom_1_1sun_1_1star_1_1sheet_1_1SheetSortDescriptor2.html#a0256ee8718a31dd4301e26891ed3c619", null ],
