@@ -1,6 +1,6 @@
 var servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE =
 [
-    [ "TextFieldMaster", "servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html#a659df1f07dd32bad5ef0b3cf676b9f2a", null ],
+    [ "com::sun::star::text::TextFieldMaster", "servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html#a659df1f07dd32bad5ef0b3cf676b9f2a", null ],
     [ "Content", "servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html#a6d1fb265b40351e94f79e0f749e5daf9", null ],
     [ "DDECommandElement", "servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html#a28ac5c6791eb9c1fd92d130c6d8840bd", null ],
     [ "DDECommandFile", "servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1DDE.html#ae614d4e217fdd8bf15a1d69830f08695", null ],
